const express = require('express');
const router = express.Router();
const Tweet = require('../models/TweetModel');

router.get('/', async (req, res) => {
  try {
    const tweets = await Tweet.find();
    res.json(tweets.reverse());
  } catch (err) {
    console.error(err);
    res.status(500).send();
  }
});

router.post('/', async (req, res) => {
  const user = req.body.user.toString();
  const content = req.body.content.toString();
  try {
    const tweet = {
      user: user,
      content: content,
      likes: [],
    };
    const newTweet = await Tweet.create(tweet);
    res.json(newTweet);
  } catch (err) {
    console.error(err);
    res.status(400).send();
  }
});

router.delete('/:tweetId', async (req, res) => {
  const tweetForDeletionId = req.params.tweetId;
  try {
    const removedTweet = await Tweet.remove({ _id: tweetForDeletionId });
    res.status(204).json(removedTweet);
  } catch (err) {
    console.error(err);
    res.status(500).send(err.message);
  }
});

module.exports = router;
