import { Twitter } from './scenes/twitter/component';
import { Routes, Route } from 'react-router-dom';
import { FrontPage } from './authComponents/frontPage';
import { LoginPage } from './authComponents/login';
import { RegisterPage } from './authComponents/register';
import { useAppStateSelector, RootState } from './redux';
import { PageNotFound } from './components/pageNotFound';
type Props = {
  handleClose: () => void;
};

function App({ handleClose }: Props) {
  const isAuthenticated = useAppStateSelector<boolean>(
    (state: RootState) => state.auth.isAuthenticated,
  );

  return (
    <>
      {!isAuthenticated ? (
        <Routes>
          <Route path="*" element={<PageNotFound />} />
          <Route path="/" element={<FrontPage />} />
          <Route path="/front" element={<FrontPage />} />
          <Route path="/register" element={<RegisterPage />} />
          <Route path="/login" element={<LoginPage />} />
        </Routes>
      ) : (
        <Routes>
          <Route path="*" element={<PageNotFound />} />
          <Route path="/" element={<Twitter handleClose={handleClose} />} />
        </Routes>
      )}
    </>
  );
}

export default App;
