import { Grid, Avatar, TextField, useMediaQuery } from '@mui/material';
import {
  PermMedia,
  GifBox,
  Poll,
  EmojiEmotions,
  DateRange,
  LocationOn,
} from '@mui/icons-material';
import './styles.css';
import { addNewTweet, getTweets } from '../../redux/tweets/actions';
import { RootState, useAppDispatch, useAppStateSelector } from '../../redux';
import { useEffect, useState } from 'react';
import { CurrentUser } from '../../redux/auth/types';

type Props = {
  handleClose: () => void;
};

export const Form = ({ handleClose }: Props) => {
  const [tweet, setTweet] = useState('');
  const [disable, setDisable] = useState(false);
  const dispatch = useAppDispatch();

  const currentUser = useAppStateSelector<CurrentUser>(
    (state: RootState) => state.auth.currentUser,
  );

  useEffect(() => {
    if (tweet === '') {
      setDisable(true);
    } else {
      setDisable(false);
    }
  }, [tweet]);

  const postTweet = async () => {
    const newTweet = {
      user: currentUser.userName,
      content: tweet,
    };
    dispatch(addNewTweet({ input: newTweet })).then(() => {
      dispatch(getTweets());
    });
    setTweet('');
    handleClose();
  };

  const handleTweetChange = (event: React.ChangeEvent<HTMLTextAreaElement>) => {
    setTweet(event.target.value);
  };

  return (
    <Grid container spacing={2}>
      <Grid item container style={{ height: 100 }}>
        <Grid item xs={1.5} style={{ paddingLeft: 15 }}>
          <Avatar
            alt={currentUser.userName.toUpperCase()}
            src="/static/images/avatar/3.jpg"
          />
        </Grid>
        <Grid item xs={10.5}>
          <TextField
            style={{ width: '90%', marginTop: 11 }}
            InputProps={{ disableUnderline: true }}
            value={tweet}
            onChange={handleTweetChange}
            placeholder="What's Happening?"
            variant="standard"
          />
        </Grid>
      </Grid>
      <Grid className="formButtonContainer" item container>
        <Grid item xs={1}></Grid>
        <Grid item xs={8}>
          <PermMedia />
          <GifBox />
          <Poll />
          <EmojiEmotions />
          <DateRange />
          <LocationOn color="disabled" />
        </Grid>
        <Grid item xs={3}>
          <button
            className="formButton"
            onClick={postTweet}
            id={disable ? 'disabledFormButton' : ''}
          >
            Tweet
          </button>
        </Grid>
      </Grid>
    </Grid>
  );
};
