import { Grid, Avatar } from '@mui/material';
import { useAppStateSelector, RootState, useAppDispatch } from '../../redux';
import { TweetsState } from '../../redux/tweets/types/tweets-dispatch-types';
import { TweetMenu } from '../tweetMenu';
import moment from 'moment';
import { CurrentUser } from '../../redux/auth/types';
import { Autorenew, Favorite, FavoriteBorder } from '@mui/icons-material';
import { addNewTweet, getTweets, likeTweet } from '../../redux/tweets/actions';

type Props = {
  onDelete: (tweetId: string) => void;
};

export const Tweet = ({ onDelete }: Props) => {
  const dispatch = useAppDispatch();
  const myTweetsState = useAppStateSelector<TweetsState>(
    (state: RootState) => state.tweets,
  );

  const currentUser = useAppStateSelector<CurrentUser>(
    (state: RootState) => state.auth.currentUser,
  );

  const reTweet = (content: string) => {
    const newTweet = {
      user: currentUser.userName,
      content: content,
    };
    dispatch(addNewTweet({ input: newTweet })).then(() => {
      dispatch(getTweets());
    });
  };

  return (
    <Grid>
      {myTweetsState.tweetsData.data.map((myTweet) => {
        return (
          <Grid item container direction="column">
            <Grid item container direction="row">
              <Grid item xs={1.5} style={{ paddingLeft: 15, paddingTop: 15 }}>
                <Avatar
                  alt={myTweet.user.toUpperCase()}
                  src="/static/images/avatar/3.jpg"
                />
              </Grid>
              <Grid item container direction="column" xs={9.5}>
                <Grid item>
                  <h4>
                    {myTweet.user} -{' '}
                    {moment(myTweet.createdAt).format('ddd h:mm A')}
                  </h4>
                </Grid>
                <Grid item>
                  <p>{myTweet.content}</p>
                </Grid>
                <Grid item>
                  <hr />
                </Grid>
              </Grid>
              <Grid item xs={1} style={{ marginLeft: -25 }}>
                <TweetMenu onDelete={onDelete} tweetId={myTweet._id} />
              </Grid>
            </Grid>
            <Grid
              item
              container
              justifyContent="space-around"
              style={{ width: '100%' }}
            >
              <Grid item>
                <FavoriteBorder
                  onClick={() => dispatch(likeTweet(myTweet._id))}
                  style={{ cursor: 'pointer' }}
                />
              </Grid>
              <Grid item>
                <Autorenew
                  onClick={() => reTweet(myTweet.content)}
                  style={{ cursor: 'pointer' }}
                />
              </Grid>
            </Grid>
            <Grid item>
              <hr />
            </Grid>
          </Grid>
        );
      })}
    </Grid>
  );
};
