import {
  AnyAction,
  applyMiddleware,
  combineReducers,
  createStore,
  Store,
} from 'redux';
import thunk from 'redux-thunk';
import { initialState as initialTweetsState, tweetsReducer } from './tweets';
import { initialState as initialAuthState, authReducer } from './auth';
import { initialState as initialUserState, userReducer } from './users';
import { Persistor, persistStore, persistReducer } from 'redux-persist';
import storage from 'redux-persist/lib/storage'; // defaults to localStorage for web

const persistConfig = {
  key: 'root',
  storage,
};

export const appReducer = combineReducers({
  tweets: tweetsReducer,
  auth: authReducer,
  user: userReducer,
});

const rootInitialState = {
  tweets: initialTweetsState,
  auth: initialAuthState,
  user: initialUserState,
};

type RootState = ReturnType<typeof appReducer>;

export const rootReducer = (
  state: RootState | undefined,
  action: AnyAction,
) => {
  return appReducer(state, action);
};

export const configureStore = (): {
  store: Store<RootState>;
  persistor: Persistor;
} => {
  const persistedReducer = persistReducer<RootState>(
    persistConfig,
    rootReducer,
  );

  const store = createStore(persistedReducer, applyMiddleware(thunk));

  const persistor = persistStore(store);

  return { store, persistor };
};
