import axios from 'axios';
import { AppDispatch } from '..';
import {
  AddTweetPayload,
  AddTweetResponsePayload,
  ADD_TWEET_FAIL,
  ADD_TWEET_LOADING,
  ADD_TWEET_SUCCESS,
} from './types/tweet-add';
import {
  LIKE_TWEET_LOADING,
  LIKE_TWEET_SUCCESS,
  LIKE_TWEET_FAIL,
} from './types/tweet-like';
import {
  REMOVE_TWEET_FAIL,
  REMOVE_TWEET_LOADING,
  REMOVE_TWEET_SUCCESS,
} from './types/tweet-remove';
import { TweetsDiispatchTypes } from './types/tweets-dispatch-types';
import {
  GET_TWEETS,
  GetTweetsResponsePayload,
  GET_TWEETS_FAIL,
  GET_TWEETS_SUCCESS,
} from './types/tweets-get';

export const getTweets =
  () => async (dispatch: AppDispatch<TweetsDiispatchTypes>) => {
    dispatch({ type: GET_TWEETS });

    return await new Promise<GetTweetsResponsePayload>((resolve, reject) => {
      axios('http://localhost:5000/tweets')
        .then((res) => {
          if (res.status >= 400) {
            throw res;
          }
          dispatch({ type: GET_TWEETS_SUCCESS, payload: res.data });
          resolve(res.data);
        })
        .catch((err) => {
          dispatch({ type: GET_TWEETS_FAIL, payload: err });
          reject(err);
        });
    });
  };

export const addNewTweet =
  (addTweetPayload: AddTweetPayload) =>
  async (dispatch: AppDispatch<TweetsDiispatchTypes>) => {
    dispatch({ type: ADD_TWEET_LOADING });

    return await new Promise<AddTweetResponsePayload>((resolve, reject) => {
      axios
        .post('http://localhost:5000/tweets', addTweetPayload.input)
        .then((res) => {
          if (res.status >= 400) {
            throw res;
          }
          dispatch({ type: ADD_TWEET_SUCCESS, payload: res.data });
          resolve(res.data);
        })
        .catch((err) => {
          dispatch({ type: ADD_TWEET_FAIL, payload: err });
          reject(err);
        });
    });
  };

export const removeTweet =
  (tweetId: string) => async (dispatch: AppDispatch<TweetsDiispatchTypes>) => {
    dispatch({ type: REMOVE_TWEET_LOADING });

    const tweetsUrl = 'http://localhost:5000/tweets/';

    return await new Promise((resolve, reject) => {
      axios
        .delete(tweetsUrl.concat(tweetId))
        .then((res) => {
          if (res.status >= 400) {
            throw res;
          }
          dispatch({ type: REMOVE_TWEET_SUCCESS, payload: tweetId });
          resolve(res.data);
        })
        .catch((err) => {
          dispatch({ type: REMOVE_TWEET_FAIL, payload: err });
          reject(err);
        });
    });
  };

export const likeTweet =
  (tweetId: string) => async (dispatch: AppDispatch<TweetsDiispatchTypes>) => {
    dispatch({ type: LIKE_TWEET_LOADING });

    const tweetsUrl = 'http://localhost:5000/tweets/like/';

    return await new Promise((resolve, reject) => {
      axios
        .put(tweetsUrl.concat(tweetId))
        .then((res) => {
          if (res.status >= 400) {
            throw res;
          }
          dispatch({ type: LIKE_TWEET_SUCCESS, payload: tweetId });
          resolve(res.data);
        })
        .catch((err) => {
          dispatch({ type: LIKE_TWEET_FAIL, payload: err });
          reject(err);
        });
    });
  };
