import {
  ADD_TWEET_FAIL,
  ADD_TWEET_LOADING,
  ADD_TWEET_SUCCESS,
} from './types/tweet-add';
import {
  LIKE_TWEET_LOADING,
  LIKE_TWEET_FAIL,
  LIKE_TWEET_SUCCESS,
} from './types/tweet-like';
import {
  REMOVE_TWEET_FAIL,
  REMOVE_TWEET_LOADING,
  REMOVE_TWEET_SUCCESS,
} from './types/tweet-remove';
import {
  TweetsDiispatchTypes,
  TweetsState,
} from './types/tweets-dispatch-types';
import {
  GET_TWEETS,
  GET_TWEETS_FAIL,
  GET_TWEETS_SUCCESS,
} from './types/tweets-get';

export const initialState: TweetsState = {
  loading: false,
  tweetsData: { data: [] },
  newTweetOutput: {
    _id: '',
    user: '',
    content: '',
    createdAt: '',
    updatedAt: '',
    likes: [],
  },
};

export const tweetsReducer = (
  state: TweetsState = initialState,
  action: TweetsDiispatchTypes,
) => {
  switch (action.type) {
    case LIKE_TWEET_LOADING:
    case REMOVE_TWEET_LOADING:
    case ADD_TWEET_LOADING:
    case GET_TWEETS: {
      return {
        ...state,
        loading: true,
      };
    }
    case GET_TWEETS_SUCCESS: {
      return {
        ...state,
        loading: false,
        tweetsData: {
          data: action.payload,
        },
      };
    }
    case LIKE_TWEET_FAIL:
    case REMOVE_TWEET_FAIL:
    case ADD_TWEET_FAIL:
    case GET_TWEETS_FAIL: {
      return {
        ...state,
        loading: false,
      };
    }
    case LIKE_TWEET_SUCCESS:
    case ADD_TWEET_SUCCESS: {
      return {
        ...state,
        newTweetOutput: action.payload.data,
      };
    }
    case REMOVE_TWEET_SUCCESS: {
      return {
        ...state,
        tweetsData: {
          data: state.tweetsData.data.filter(
            (tweet) => !(tweet._id === action.payload),
          ),
        },
      };
    }
    default:
      return state;
  }
};
