import {
  List,
  ListItem,
  ListItemButton,
  ListItemIcon,
  ListItemText,
  Grid,
  useMediaQuery,
  Avatar,
  IconButton,
  Menu,
  MenuItem,
} from '@mui/material';
import {
  Home,
  Tag,
  NotificationsNone,
  MailOutline,
  BookmarkBorder,
  ListAlt,
  PermIdentity,
  MoreHoriz,
  Twitter,
  Logout,
  MoreVert,
} from '@mui/icons-material';
import { useNavigate } from 'react-router-dom';
import { TwitterButton } from '../../components/twitterButton';
import { theme } from '../../theme';
import { useAppStateSelector, RootState, useAppDispatch } from '../../redux';
import { CurrentUser } from '../../redux/auth/types';
import { useState } from 'react';
import { logout } from '../../redux/auth/actions';

export const TwitterMenu = () => {
  const smallScreen = useMediaQuery(theme.breakpoints.down('sm'));
  const mediumScreen = useMediaQuery(theme.breakpoints.down('md'));
  const [anchorEl, setAnchorEl] = useState<null | HTMLElement>(null);
  const open = Boolean(anchorEl);
  const dispatch = useAppDispatch();

  const handleClick = (event: React.MouseEvent<HTMLElement>) => {
    setAnchorEl(event.currentTarget);
  };
  const handleClose = () => {
    setAnchorEl(null);
  };

  const currentUser = useAppStateSelector<CurrentUser>(
    (state: RootState) => state.auth.currentUser,
  );

  return (
    <Grid
      container
      direction="column"
      justifyContent="space-between"
      style={{ height: 930, position: 'sticky', top: 10 }}
    >
      <Grid item direction="column" xs={11}>
        <nav aria-label="main mailbox folders">
          <List>
            <ListItem disablePadding>
              <ListItemButton>
                <ListItemIcon>
                  <Twitter />
                </ListItemIcon>
              </ListItemButton>
            </ListItem>
            <ListItem disablePadding>
              <ListItemButton>
                <ListItemIcon>
                  <Home />
                </ListItemIcon>
                {!smallScreen && !mediumScreen && (
                  <ListItemText primary="Home" style={{ marginLeft: -15 }} />
                )}
              </ListItemButton>
            </ListItem>
            <ListItem disablePadding>
              <ListItemButton>
                <ListItemIcon>
                  <Tag />
                </ListItemIcon>
                {!smallScreen && !mediumScreen && (
                  <ListItemText primary="Explore" style={{ marginLeft: -15 }} />
                )}
              </ListItemButton>
            </ListItem>
            <ListItem disablePadding>
              <ListItemButton>
                <ListItemIcon>
                  <NotificationsNone />
                </ListItemIcon>
                {!smallScreen && !mediumScreen && (
                  <ListItemText
                    primary="Notifications"
                    style={{ marginLeft: -15 }}
                  />
                )}
              </ListItemButton>
            </ListItem>
            <ListItem disablePadding>
              <ListItemButton>
                <ListItemIcon>
                  <MailOutline />
                </ListItemIcon>
                {!smallScreen && !mediumScreen && (
                  <ListItemText
                    primary="Messages"
                    style={{ marginLeft: -15 }}
                  />
                )}
              </ListItemButton>
            </ListItem>
            <ListItem disablePadding>
              <ListItemButton>
                <ListItemIcon>
                  <BookmarkBorder />
                </ListItemIcon>
                {!smallScreen && !mediumScreen && (
                  <ListItemText
                    primary="Bookmarks"
                    style={{ marginLeft: -15 }}
                  />
                )}
              </ListItemButton>
            </ListItem>
            <ListItem disablePadding>
              <ListItemButton>
                <ListItemIcon>
                  <ListAlt />
                </ListItemIcon>
                {!smallScreen && !mediumScreen && (
                  <ListItemText primary="Lists" style={{ marginLeft: -15 }} />
                )}
              </ListItemButton>
            </ListItem>
            <ListItem disablePadding>
              <ListItemButton>
                <ListItemIcon>
                  <PermIdentity />
                </ListItemIcon>
                {!smallScreen && !mediumScreen && (
                  <ListItemText primary="Profile" style={{ marginLeft: -15 }} />
                )}
              </ListItemButton>
            </ListItem>
            <ListItem disablePadding>
              <ListItemButton>
                <ListItemIcon>
                  <MoreHoriz />
                </ListItemIcon>
                {!smallScreen && !mediumScreen && (
                  <ListItemText primary="More" style={{ marginLeft: -15 }} />
                )}
              </ListItemButton>
            </ListItem>
          </List>
        </nav>
        <TwitterButton />
      </Grid>
      <Grid item container xs={1} direction="row">
        <Grid item container xs={10}>
          <Grid item container>
            <Grid item>
              <Avatar
                alt={currentUser.userName.toUpperCase()}
                src="/static/images/avatar/3.jpg"
              />
            </Grid>
            <Grid item style={{ paddingLeft: 15 }}>
              <p>{currentUser.userName}</p>
            </Grid>
          </Grid>
        </Grid>
        <Grid item xs={2}>
          <IconButton
            aria-label="more"
            id="long-button"
            aria-controls={open ? 'long-menu' : undefined}
            aria-expanded={open ? 'true' : undefined}
            aria-haspopup="true"
            onClick={handleClick}
          >
            <MoreVert />
          </IconButton>
          <Menu
            id="long-menu"
            MenuListProps={{
              'aria-labelledby': 'long-button',
            }}
            anchorEl={anchorEl}
            open={open}
            onClose={handleClose}
            PaperProps={{
              style: {
                width: '20ch',
              },
            }}
          >
            <MenuItem onClick={() => dispatch(logout())}>
              <Logout />
              Logout
            </MenuItem>
          </Menu>
        </Grid>
      </Grid>
    </Grid>
  );
};
