import { Grid, useMediaQuery } from '@mui/material';
import { useEffect } from 'react';
import { getTweets } from '../../redux/tweets/actions';
import { useAppDispatch } from '../../redux/use-app-dispatch';
import { theme } from '../../theme';
import { TwitterMenu } from '../menu';
import { SideBar } from '../sideBar';
import { Wall } from '../wall';
import './styles.css';

type Props = {
  handleClose: () => void;
};

export const Twitter = ({ handleClose }: Props) => {
  const smallScreen = useMediaQuery(theme.breakpoints.down('sm'));
  const dispatch = useAppDispatch();

  useEffect(() => {
    dispatch(getTweets());
  }, []);

  return (
    <Grid container spacing={6} justifyContent={'center'}>
      <Grid item xs={2} sm={2}>
        <TwitterMenu />
      </Grid>
      <Grid item xs={4} sm={4}>
        <Wall handleClose={handleClose} />
      </Grid>
      {!smallScreen && (
        <Grid item xs={3} sm={3}>
          <SideBar />
        </Grid>
      )}
    </Grid>
  );
};
