import { Grid } from '@mui/material';
import './styles.css';
import { Tweet } from '../../components/tweet';
import { Form } from '../../components/form';
import { ConfirmDialog } from '../../components/confirmDialog';
import { useState } from 'react';
import { getTweets, removeTweet } from '../../redux/tweets/actions';
import { useConfirmDialog } from '../../components/UseConfirmDialog';
import { useAppDispatch } from '../../redux';

type Props = {
  handleClose: () => void;
};

export const Wall = ({ handleClose }: Props) => {
  const [tweetForDeletion, setTweetForDeletion] = useState('');
  const { open, openDialog, closeDialog } = useConfirmDialog();
  const dispatch = useAppDispatch();

  const onDelete = (tweetId: string) => {
    setTweetForDeletion(tweetId);
    openDialog();
  };

  const triggerDeletion = () => {
    if (!tweetForDeletion) {
      return;
    }
    closeDialog();
    dispatch(removeTweet(tweetForDeletion)).then(() => {
      dispatch(getTweets());
    });
  };

  return (
    <Grid container direction="column" className="wall" spacing={2}>
      <Grid item container spacing={2}>
        <Grid item>
          <h2>Home</h2>
        </Grid>
        <Form handleClose={handleClose} />
      </Grid>
      <Grid item>
        <hr className="divider" />
      </Grid>
      <Tweet onDelete={onDelete} />
      <ConfirmDialog
        title={'Warning'}
        message={'Are you sure you want to remove this tweet?'}
        firstButtonText={'cancel'}
        secondButtonText={'delete'}
        openDialog={open}
        onConfirm={triggerDeletion}
        onCancel={closeDialog}
      />
    </Grid>
  );
};
